<?php

namespace EventPortal\Domain\Delegate\Models;

use EventPortal\Domain\Event\Form\Enums\State;
use EventPortal\Domain\Event\Form\Models\FormStep;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Enum\Laravel\HasEnums;

class DelegateFormStep extends Model implements AuditableInterface
{
    use HasEnums, Auditable;

    const KEY = 'delegate_form_step';

    /** @var string */
    protected $table = 'delegate_form_step';

    /** @var array<string,mixed> */
    protected $enums = [
        'state' => State::class,
    ];

    /** @var array */
    protected $fillable = [
        'state',
        'delegate_id',
        'form_step_id',
    ];

    /** @var array<string> */
    public $with = [
        'delegate',
        'step',
    ];

    public function delegate(): BelongsTo
    {
        return $this->belongsTo(Delegate::class);
    }

    public function step(): BelongsTo
    {
        return $this->belongsTo(FormStep::class, 'form_step_id');
    }
}
