<?php

namespace EventPortal\Http\Controllers\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\AdminRender as Render;
use EventPortal\Domain\Util\Sidebar\Facades\Sidebar;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Inertia\Response;

class SignInController extends Controller
{
    public function index(Event $event): Response
    {
        $query = EventDelegate::select(
            [
                'delegate_event.id',
                'sign_ins.signed_in_at',
                'sign_ins.signed_out_at',
                'delegate_event.event_id',
                'users.first_name',
                'users.last_name',
            ]
        )
            ->join('delegates', 'delegates.id', '=', 'delegate_event.delegate_id')
            ->join('users', 'users.id', '=', 'delegates.user_id')
            ->withSignins()
            ->where('delegate_event.event_id', $event->id);

        $table = Table::make('event.sign-in.index')
            ->query($query)
            ->context($event)
            ->request(request())
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->model(request()->event)
            ->render();

        return Render::component('Admin/EventSignIn/Index')
            ->key('event.sign-in.index')
            ->withTable($table)
            ->withSideBar($sidebar)
            ->get();
    }

    public function update(Event $event, EventDelegate $eventDelegate): RedirectResponse
    {
        $eventDelegate->toggleSignInAt($event);

        if ($eventDelegate->canApply('attended')) {
            $eventDelegate->apply('attended');
            $eventDelegate->save();
        }

        return redirect()->back();
    }
}
