<?php

namespace EventPortal\Tests\Feature\Delegate\Event;

use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\EventDelegate\RegistrationStatus;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Http\Response;

class CanDelegateViewFormMiddlewareTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function delegate_can_view_decline_form(): void
    {
        $states = [
            RegistrationStatus::invited(),
            RegistrationStatus::declining(),
            RegistrationStatus::declined(),
        ];

        foreach ($states as $state) {
            $this->assertDelegateCanViewDeclineForm($state);
        }
    }

    /** @test */
    public function delegate_cannot_view_decline_form(): void
    {
        $states = [
            RegistrationStatus::candidate(),
            RegistrationStatus::registering(),
            RegistrationStatus::registered(),
            RegistrationStatus::attended(),
            RegistrationStatus::cancelled(),
            RegistrationStatus::no_show(),
        ];

        foreach ($states as $state) {
            $this->assertDelegateCannotViewDeclineForm($state);
        }
    }

    private function assertDelegateCanViewDeclineForm(string $eventDelegateState)
    {
        [$eventDelegate, $form] = $this->setupData($eventDelegateState, 'decline');

        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('delegate.form.index', [
                'form' => $form->slug,
                'event' => $eventDelegate->event->slug,
            ]))
            ->assertStatus(Response::HTTP_OK);
    }

    private function assertDelegateCannotViewDeclineForm(string $eventDelegateState)
    {
        [$eventDelegate, $form] = $this->setupData($eventDelegateState, 'decline');

        $this
            ->actingAsDelegate($eventDelegate->delegate)
            ->get(route('delegate.form.index', [
                'form' => $form->slug,
                'event' => $eventDelegate->event->slug,
            ]))
            ->assertStatus(Response::HTTP_FORBIDDEN);
    }

    private function setupData(string $eventDelegateState, string $formType)
    {
        $eventDelegate = factory(EventDelegate::class)->state($eventDelegateState)->create();
        $form = factory(Form::class)->state($formType)->create(['event_id' => $eventDelegate->event->id]);
        $step = factory(FormStep::class)->create(['form_id' => $form->id]);
        $section = factory(FormStepSection::class)->create(['form_step_id' => $step->id]);
        factory(Question::class)->create(['form_step_section_id' => $section->id]);

        return [$eventDelegate, $form];
    }
}
